# User Guide

In this section we provide material how to use xradar.

Most of the material is distributed as juypter notebooks to be able to interactively explore xradar functionality.

To use xradar in a project:

```python
import xradar
```

```{toctree}
:maxdepth: 2
:caption: Get started

datamodel
importers
notebooks/Accessors
```

```{toctree}
:maxdepth: 2
:caption: Examples

notebooks/CfRadial1
notebooks/CfRadial1_full
notebooks/ODIM_H5
notebooks/ODIM_H5_full
```
